@@ -65,7 +65,7 @@ class CompilationError < RuntimeError; end
 # the current namespace.
 
 module Inline
-  VERSION = '3.8.1'
+  VERSION = '3.8.3'
 
   WINDOZE  = /mswin|mingw/ =~ RUBY_PLATFORM
   RUBINIUS = defined? RUBY_ENGINE
@@ -647,6 +647,14 @@ VALUE #{method}_equals(VALUE value) {
       @libs.push(*flags)
     end
 
+    ##
+    # Create a static variable and initialize it to a value.
+
+    def add_static name, init, type = "VALUE"
+      prefix      "static #{type} #{name};"
+      add_to_init "#{name} = #{init};"
+    end
+
     ##
     # Adds custom content to the end of the init function.
 
